multidim.Simplex.height — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- Multidimensional Data
- multidim.Simplex

- index
- modules
- next
- previous

# multidim.Simplex.height

`Simplex.` `height`

  Returns: | height (that is, filtered value) of this cell (np.float64)

#### Previous topic

multidim.Simplex.boundary

#### Next topic

multidim.Simplex.mass

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.